<?php

defined('_JEXEC') or die;


class plgJKPaySystemPayAnyWay extends JPlugin
{

	// Названия полей формы PayAnyWay
	const MNT_ID = "MNT_ID";
	const MNT_TRANSACTION_ID = "MNT_TRANSACTION_ID";
	const MNT_AMOUNT = "MNT_AMOUNT";
	const MNT_CURRENCY_CODE = "MNT_CURRENCY_CODE";
	const MNT_TEST_MODE = "MNT_TEST_MODE";
	const MNT_DESCRIPTION = "MNT_DESCRIPTION";
	const MNT_SUBSCRIBER_ID = "MNT_SUBSCRIBER_ID";
	const MNT_SIGNATURE = "MNT_SIGNATURE";
	const MNT_CUSTOM1 = "MNT_CUSTOM1";
	const MNT_CUSTOM2 = "MNT_CUSTOM2";
	const MNT_CUSTOM3 = "MNT_CUSTOM3";
	const MNT_LOCALE = "moneta.locale";
	const MNT_OPERATION_ID = "MNT_OPERATION_ID";
	// Ответы на Pay URL
	const MNT_ANSWER_SUCCESS = "PAYANYWAY_PAYMENT_SUCCESS";
	const MNT_ANSWER_FAIL = "PAYANYWAY_PAYMENT_FAIL";


	/**
	 * Options для списка выбора систем платежа.
	 * Выводится: в конфигурации JoomlaKassa, менеджере продукта, пункте меню "Один продукт", при редактировании продукта (front-end).
	 * Также в списке выбора системы платежа в форме заказа.
	 *
	 * @param	float		$total		Сумма платежа, переданная со страницы заказа (order)
	 * @param	string		$cur_code	Код валюты (только для order)
	 * @param	string		$checked	Ключ выбранной системы по умолчанию (устанавливается в конфигурации компонента)
	 *
	 * @return  mixed		JHtml::tooltip с input в качестве HTML – для списка в форме платежа.
	 *						JHtml::select.option – для параметров компонента.
	 */
    function selectSystem($total, $cur_code = '', $checked = '')
	{
		// Проверяем параметры конфигурации, если они не установлены, возвращаем false
		$mnt_id = $this->params->def('mnt_id');
		$mnt_dataintegrity_code = $this->params->def('mnt_dataintegrity_code');
		$paw_test_mode = $this->params->def('paw_test_mode');
		$payment_action = $this->params->def('payment_action');
		if (empty($mnt_id) || empty($mnt_dataintegrity_code) || empty($paw_test_mode) || empty($payment_action))
			return false;
		
		$key_system  = $this->params->def('key_system');
		$system_name = $this->params->def('system_name');
		
		// Вызов с order
		if ($cur_code)
		{
			// Если выбранная валюта не соответствует валюте в плагине
			// if ($cur_code != 'RUB') return false;
			
			$system_logo = $this->params->def('system_logo');
			$system_desc = $this->params->def('system_desc');
			$app		 = JFactory::getApplication();
			
			// checked
			$select = $app->input->get('select', '', 'post'); // Если в URL есть select=(key_system)
			if (!$select) {
				$checked = ($checked == $key_system) ? ' checked' : '';
			}
			else {
				$checked = ($select == $key_system) ? ' checked' : '';
			}
			
			// radio
			$tip = JHTML::_('image', $system_logo, $key_system) .'<br />'. $system_desc;
			$radio = '<input type="radio" name="service_payment" value="'.$key_system.'"'.$checked.' /> '.$system_name;
			
			return JHtml::tooltip($tip, '', '', $radio);
		}
		
		// Объект на основе <option /> элемента
		return JHtml::_('select.option', $key_system, $system_name);
	}
	
	
	/**
	 * Дополнительная кнопка, расположенная на странице продукта возле кнопки "Купить" и "В корзину".
	 *
	 * @param	int			$product_id			ID продукта
	 * @param	string		$product_name		Наименование продукта
	 * @param	float		$payment_amount		Стоимость продукта (по умолчанию)
	 * @param	float		$product_cost		Стоимость продукта (по курсу)
	 * @param	string		$currency_code		Код валюты
	 * @param	base64		$variants_data		Варианты продукта
	 * @param	int			$desc_discount		Значение скидки
	 * 
	 * @return  string		HTML кнопки
	 */
    #function btnProduct($product_id, $product_name, $payment_amount, $product_cost, $currency_code, $variants_data, $desc_discount) {  }
	
	
	/**
	 * Передача данных обработчику заказа (task=order.orderform)
	 *
	 * @param	string		$system			Ключ системы платежа
	 * @param	float		$pm_amount		Сумма платежа
	 * @param	string		$pm_desc		Описание платежа
	 * @param	string		$name			Имя покупателя
	 * @param	string		$email			Email покупателя
	 * @param	string		$mob_phone		Мобильный телефон
	 * @param	string		$cur_code		Код валюты
	 * @param	float		$cur_cours		Курс валюты
	 * @param	string		$order_pass		Пароль заказа
	 * 
	 * @return  array	name		string		Имя системы платежа
						logo		string		Путь к логотипу системы платежа
	 					id			string		ID кассы/магазина в системе платежа
						pm_number	string		ID платежа
						form		string		HTML формы платежа
						js			string		JavaScript для формы платежа (без тегов: <script type="text/javascript">…</script>)
	 */
	function order($system, $pm_amount, $pm_desc, $name, $email, $mob_phone, $cur_code, $cur_cours, $order_pass)
	{
		$key_system = $this->params->def('key_system');
		
		// Если ключ системы не относится к PAYANYWAY
		if ($system != $key_system)
			return false;
		
		$params = array();

		$mnt_dataintegrity_code = $this->params->def('mnt_dataintegrity_code');
		$params[self::MNT_ID] = $this->params->def('mnt_id');
		$params[self::MNT_TRANSACTION_ID] = uniqid('', true);	// генерируем ID транзакции
		$params[self::MNT_AMOUNT] = number_format($pm_amount, 2, '.', '');
		$params[self::MNT_CURRENCY_CODE] = $cur_code;
		$params[self::MNT_SUBSCRIBER_ID] = $email;
		$params[self::MNT_DESCRIPTION] = $pm_desc;
		$params[self::MNT_CUSTOM1] = $name;
		$params[self::MNT_CUSTOM2] = $mob_phone;
		$params[self::MNT_CUSTOM3] = $order_pass;
		$params[self::MNT_LOCALE] = $this->params->def("language");

		// Задаем ACTION для формы
		$action = $this->params->def('payment_action');

		// Проверяем тестовый режим, если выбран режим внутреннего тестирования, меняем ACTION
		if ($this->params->def('paw_test_mode') == "INT") {
			$action = 'index.php?option=com_joomlakassa&view=test&system='.$key_system; // тестовый режим компонента
		}
		if ($this->params->def('paw_test_mode') == "ON")
		{
			$params[self::MNT_TEST_MODE] = '1';
		}
		else
		{
			$params[self::MNT_TEST_MODE] = '0';
		}

		// Формируем подпись
		$params[self::MNT_SIGNATURE] = md5
		(
			$params[self::MNT_ID].
			$params[self::MNT_TRANSACTION_ID].
			$params[self::MNT_AMOUNT].
			$params[self::MNT_CURRENCY_CODE].
			$params[self::MNT_SUBSCRIBER_ID].
			$params[self::MNT_TEST_MODE].
			$mnt_dataintegrity_code
		);

		// Форма для отправки
		$form  = "\n<form name=\"payment\" action=\"{$action}\" method=\"post\" id=\"jkActionSubmit\">\n";
		foreach(
			array (
				self::MNT_ID,
				self::MNT_TRANSACTION_ID,
				self::MNT_AMOUNT,
				self::MNT_CURRENCY_CODE,
				self::MNT_TEST_MODE,
				self::MNT_DESCRIPTION,
				self::MNT_SUBSCRIBER_ID,
				self::MNT_SIGNATURE,
				self::MNT_CUSTOM1,
				self::MNT_CUSTOM2,
				self::MNT_CUSTOM3
			) as $param)
		{
			$form .= "<input type=\"hidden\" name=\"{$param}\" value=\"{$params[$param]}\" />\n";
		}

		$form .= '</form>\n';

		return array (
			"name" => $this->params->def("system_name"),
			"logo" => $this->params->def("system_logo"),
			"id" => $params[self::MNT_ID],
			"pm_number" => $params[self::MNT_TRANSACTION_ID],
			"form" => $form,
			"js" => "",
		);
	}


	/**
	 * Тестовая страница системы платежа (view - test)
	 *
	 * @param	string		$system		Ключ системы платежа
	 *
	 * @return  string		
	 */
	function test($system)
	{
		// Если ключ системы не относится к PAYANYWAY
		if ($system != $this->params->def('key_system'))
			return false;
		
		$app = JFactory::getApplication();
			
		$params = array();
		// Получаем принятые параметры из формы в хэш $params:
		foreach(
			array (
				self::MNT_ID,
				self::MNT_TRANSACTION_ID,
				self::MNT_AMOUNT,
				self::MNT_CURRENCY_CODE,
				self::MNT_TEST_MODE,
				self::MNT_DESCRIPTION,
				self::MNT_SUBSCRIBER_ID,
				self::MNT_SIGNATURE,
				self::MNT_CUSTOM1,
				self::MNT_CUSTOM2,
				self::MNT_CUSTOM3
			) as $param)
		{
			$params[$param] = $app->input->get($param, '', 'post');
		}
		// получаем из конфигурации значение MNT_DATAINTEGRITY_CODE
		$mnt_dataintegrity_code = $this->params->def('mnt_dataintegrity_code');
		// генерируем MNT_OPERATION_ID
		$params[self::MNT_OPERATION_ID] = uniqid('', true);

		// Формируем подпись для Pay URL
		$mnt_signature = md5
		(
			$params[self::MNT_ID].
			$params[self::MNT_TRANSACTION_ID].
			$params[self::MNT_OPERATION_ID].
			$params[self::MNT_AMOUNT].
			$params[self::MNT_CURRENCY_CODE].
			$params[self::MNT_SUBSCRIBER_ID].
			$params[self::MNT_TEST_MODE].
			$mnt_dataintegrity_code
		);

		// ACTION формы
//		$payURL           = 'index.php?option=com_joomlakassa&task=result.interaction&system='.$this->params->def('key_system');

		$payURL = JURI::root().'plugins/jkpaysystem/payanyway/payurl.php';

		// Логотип системы
		$html = '<p style="text-align:center">'.JHtml::_('image', $this->params->def('system_logo'), $this->params->def('key_system')).'</p>';
		
		// Информация передаваемая системе
		$html .= "
		<ul>
		  <li><strong>Идентификатор магазина:</strong> {$params[self::MNT_ID]}</li>
		  <li><strong>Идентификатор заказа:</strong> {$params[self::MNT_TRANSACTION_ID]}</li>
		  <li><strong>Сумма оплаты:</strong> {$params[self::MNT_AMOUNT]}</li>
		  <li><strong>ISO код валюты:</strong> {$params[self::MNT_CURRENCY_CODE]}</li>
		  <li><strong>Тестовый режим:</strong> {$params[self::MNT_TEST_MODE]}</li>
		  <li><strong>Описание оплаты:</strong> {$params[self::MNT_DESCRIPTION]}</li>
		  <li><strong>Идентификатор пользователя:</strong> {$params[self::MNT_SUBSCRIBER_ID]}</li>
		  <li><strong>Подпись формы оплаты:</strong> {$params[self::MNT_SIGNATURE]}</li>
		  <li><strong>Произвольный параметр №1:</strong> {$params[self::MNT_CUSTOM1]}</li>
		  <li><strong>Произвольный параметр №2:</strong> {$params[self::MNT_CUSTOM2]}</li>
		  <li><strong>Произвольный параметр №3:</strong> {$params[self::MNT_CUSTOM3]}</li>
		</ul>
		";
		
		$html .= '<h2>Выполнить запрос "Pay URL"</h2>';
		$html .= '<p>Уведомление об оплате PayAnyWay отсылает на указанную страницу магазина «Pay URL» в виде '.
			'HTTP запроса методом GET или POST. В случае, если система PayAnyWay не получает ответ от магазина на '.
			'отправленный запрос с уведомлением (например, из-за недоступности системы учета магазина), будут '.
			'произведены попытки отправить уведомление в автоматическом режиме в течение суток. По истечении периода '.
			'автоматической отправки уведомлений уполномоченные сотрудники магазина или администраторы системы '.
			'PayAnyWay могут отправить уведомление в ручном режиме.</p>';
		
		// Pay URL
		$html .= '
		<div style="width:33%; float:left; text-align: center;">
		  <form action="'.$payURL.'" method="post" name="payURL" target="_blank">';
		foreach(
			array(
				self::MNT_ID,
				self::MNT_TRANSACTION_ID,
				self::MNT_OPERATION_ID,
				self::MNT_AMOUNT,
				self::MNT_CURRENCY_CODE,
				self::MNT_SUBSCRIBER_ID,
				self::MNT_TEST_MODE,
				self::MNT_CUSTOM1,
				self::MNT_CUSTOM2,
				self::MNT_CUSTOM3
			) as $param)
		{
			$html .= "\n<input type=\"hidden\" name=\"{$param}\" value=\"{$params[$param]}\" />";
		}
		$html .= '
			<input type="hidden" name="'.self::MNT_SIGNATURE.'" value="'.$mnt_signature.'" />
			<input type="submit" class="button btn btn-success" value="Pay URL">
		  </form>
		</div>
		';

		$html .= '<div style="clear: both;">&nbsp;</div>';
		
		return $html;
	}


	const paw_kassa_VAT0     = '1104';  // НДС 0%
	const paw_kassa_VAT10    = '1103';  // НДС 10%
	const paw_kassa_VAT18    = '1102';  // НДС 18%
	const paw_kassa_VATNOVAT = '1105';  // НДС не облагается
	const paw_kassa_VATWR10  = '1107';  // НДС с рассч. ставкой 10%
	const paw_kassa_VATWR18  = '1106';  // НДС с рассч. ставкой 18%
	const paw_kassa_msign    = 'joomlakassa3';

private static function cleanProductName($value)
{
	$result = preg_replace('/[^0-9a-zA-Zа-яА-Я ]/ui', '', htmlspecialchars_decode($value));
	//$result = trim(mb_substr($result, 0, 20));
	return $result;
}

private static function paw_kassa_sale($mnt_id, $mnt_transaction_id, $mnt_amount, $mnt_data_integrity_code, $client_email, $inventoryPositions)
{
	$productsTototal = 0;
	foreach ($inventoryPositions AS $item) {
		$productsTototal = $productsTototal + floatval($item['price']) * floatval($item['quantity']);
	}

	if (floatval($productsTototal) != floatval($mnt_amount)) {
		$discountRate = floatval($mnt_amount) / floatval($productsTototal);
		$newInvenrory = array();
		foreach ($inventoryPositions AS $item) {
			$item['price'] = round(floatval($item['price']) * $discountRate, 5);
			$newInvenrory[] = $item;
		}
		$inventoryPositions = $newInvenrory;
	}

	$data = array(
		'id' => $mnt_transaction_id,
		'checkoutDateTime' => date(DATE_ATOM),
		'docNum' => $mnt_transaction_id,
		'docType' => 'SALE',
		'responseURL' => 'https://kassa.payanyway.ru/index.php?do=callback',
		'inventPositions' => $inventoryPositions,
		'moneyPositions' => array(array('paymentType' => 'CARD', 'sum' => $mnt_amount))
	);
	$data['email'] = $client_email;
	$data['signature'] = md5($data['id'].$data['checkoutDateTime'].$mnt_data_integrity_code);
	if (isset($_SERVER['HTTP_HOST']))
		$domainName = $_SERVER['HTTP_HOST'];
	else
		$domainName = $_SERVER['SERVER_NAME'];

	$data['telemetry'] = array('sign' => self::paw_kassa_msign, 'domain' => $domainName);

	$jsonData = preg_replace_callback('/\\\\u(\w{4})/', function ($matches) {
		return html_entity_decode('&#x' . $matches[1] . ';', ENT_COMPAT, 'UTF-8');
	}, json_encode($data));

	$operationUrl = 'https://kassa.payanyway.ru/api/api.php?method=sale&accountid='.$mnt_id;
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $operationUrl);
	curl_setopt($ch, CURLOPT_POST, true);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonData);
	curl_setopt($ch, CURLOPT_CUSTOMREQUEST, "POST");
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($ch, CURLOPT_HTTPHEADER, array(
		'Content-Type: application/json',
		'Content-Length: '.strlen($jsonData)
	));

	$result = curl_exec($ch);
	curl_close($ch);
	return $result;
}


	/**
	 * Pay URL (проверка платежа)
	 *
	 * @param	string	$system			Ключ системы платежа
	 *
	 * @return  array	syst_id			ID магазина в системе платежа
	 *					syst_key		Ключ системы платежа
	 *					syst_name		Наименование системы платежа
	 *					syst_logo		Логотип системы платежа
	 *					syst_extra		Дополнительная информация, переданная системой платежа
	 *					pm_number		Номер платежа (создаётся в JoomlaKassa)
	 *					pm_amount		Сумма платежа
	 *					pm_desc			Описание платежа
	 *					ff_name			Имя покупателя
	 *					ff_email		Email покупателя
	 *					mob_phone		Мобильный телефон
	 *					timestamp		Время создания платежа
	 *					status			Состояние платежа
	 *					sign			Результат проверки контрольной подписи (0 - провалена, 1 - пройдена, -2 - не определена) *
	 *					data_ia			Все полученные данные от системы платежа (json)
	 */
	function interaction($system)
	{
		// Если ключ системы не относится к PAYANYWAY
		if ($system != $this->params->def('key_system'))
			return false;
		
		JHtml::addIncludePath(JPATH_ROOT.'/components/com_joomlakassa/helpers');

		$app = JFactory::getApplication();

		JRequest::setVar('tmpl','component');
		JResponse::setHeader('Content-Type', 'text/plain', TRUE);

		// получаем из конфигурации значение MNT_DATAINTEGRITY_CODE
		$mnt_dataintegrity_code = $this->params->def('mnt_dataintegrity_code');
		$mnt_kassa = $this->params->def('mnt_kassa');
		// статус интеракции
		$status	= 0; // 0 - ошибка, -1 - успех

		$params = array();
		// Получаем принятые параметры из формы в хэш $params:
		foreach(
			array(
				self::MNT_ID,
				self::MNT_TRANSACTION_ID,
				self::MNT_OPERATION_ID,
				self::MNT_AMOUNT,
				self::MNT_CURRENCY_CODE,
				self::MNT_SUBSCRIBER_ID,
				self::MNT_TEST_MODE,
				self::MNT_SIGNATURE,
				self::MNT_CUSTOM1,
				self::MNT_CUSTOM2,
				self::MNT_CUSTOM3
			) as $param)
		{
			$params[$param] = $app->input->get($param, '', 'post');
		}

		// Подготовим данные формы в JSON-формате
		$dataSet		= $app->input->getArray($_POST);
		$dataSetJson	= json_encode($dataSet);
		
		// Проверяем сумму платежа, ID транзакции и MD5-подпись
		if (JHtml::_('gswork.checkPayment', $params[self::MNT_AMOUNT], $params[self::MNT_TRANSACTION_ID])) // Проверить стоимость платежа
		{
			// Проверка контрольной подписи
			$mnt_signature = md5
			(
				$params[self::MNT_ID].
				$params[self::MNT_TRANSACTION_ID].
				$params[self::MNT_OPERATION_ID].
				$params[self::MNT_AMOUNT].
				$params[self::MNT_CURRENCY_CODE].
				$params[self::MNT_SUBSCRIBER_ID].
				$params[self::MNT_TEST_MODE].
				$mnt_dataintegrity_code
			);
			if ($mnt_signature == $params[self::MNT_SIGNATURE]) {

				try
				{
					$db = JFactory::getDBO();
					$query = "SELECT * FROM #__joomlakassa_orders WHERE " . $db->quoteName('pm_number') . " = " . $db->quote($params[self::MNT_TRANSACTION_ID]);
					$db->setQuery($query);
					$payment = $db->loadAssoc();

					if (!empty($payment) && $mnt_kassa == '1')
					{

						$products = json_decode($payment['products']);
						$delivery = json_decode($payment['delivery']);
						$userEmail = $payment['ff_email'];

						$inventoryPositions = array();
						foreach ($products as $product)
						{
							$inventoryPositions[] = array(
								'name' => self::cleanProductName($product->name),
								'price' => $product->payment / $product->number,
								'quantity' => $product->number,
								'vatTag' => self::paw_kassa_VATNOVAT
							);
						}
						if (!empty($delivery))
						{
							$inventoryPositions[] = array(
								'name' => self::cleanProductName($delivery->name),
								'price' => $delivery->cost,
								'quantity' => 1,
								'vatTag' => self::paw_kassa_VATNOVAT
							);
						}
						self::paw_kassa_sale($params[self::MNT_ID], $params[self::MNT_TRANSACTION_ID], $params[self::MNT_AMOUNT],
							$mnt_dataintegrity_code, $userEmail, $inventoryPositions);
					}

				}
				catch (Exception $e)
				{
					;
				}

				echo self::MNT_ANSWER_SUCCESS;	// печатаем успешный ответ
				$sign = 1; 							// проверка подписи пройдена
				$status = -1; 						// устанавливаем статус
				// удаляем товары из корзины
				$db = JFactory::getDBO();
				$query = "SELECT id_user FROM #__joomlakassa_orders WHERE ".$db->quoteName('pm_number')." = ".$db->quote($params[self::MNT_TRANSACTION_ID]);
				$db->setQuery($query);
				$user_id = $db->loadResult();
				JHtml::_('gswork.removedfromcart', null/*$getcart*/, $user_id, null/*$this->params->def('time_cart', 30)*/);
			}
			else
			{
				echo self::MNT_ANSWER_FAIL;			// печатаем ответ-отказ
				$sign = 0; 							// проверка подписи не пройдена
			}
		}
		else
		{
			echo self::MNT_ANSWER_FAIL;				// печатаем ответ-отказ
			$sign = -2; 							// результат проверки подписи не определен
		}

		return array(
			"syst_id" => $params[self::MNT_ID],
			"syst_key" => $this->params->def('key_system'),
			"syst_name" => $this->params->def('system_name'),
			"syst_logo" => $this->params->def('system_logo'),
			"syst_extra" => "",
			"pm_number" => $params[self::MNT_TRANSACTION_ID],
			"pm_amount" => $params[self::MNT_AMOUNT],
			"pm_desc" => "",
			"ff_name" => "",
			"ff_email" => "",
			"mob_phone" => "",
			"timestamp" => JHtml::date(strtotime("now"), 'Y-m-d H:i:s'),
			"status" => $status,
			"sign" => $sign,
			"data_ia" => $dataSetJson,
		);
	}


	/**
	 * Success Page (страница успешного платежа)
	 *
	 * @param	string	$system			Ключ системы платежа
	 *
	 * @return  array	syst_id			ID магазина в системе платежа
	 *					syst_name		Наименование системы платежа
	 *					syst_extra		Дополнительная информация, переданная системой платежа
	 *					pm_number		ID платежа в компоненте
	 *					pm_amount		Сумма платежа
	 *					ff_name			Имя покупателя
	 *					ff_email		Email покупателя
	 *					mob_phone		Мобильный телефон
	 *					timestamp		Время создания платежа
	 *					status			Состояние платежа
	 *					data_suc		Все полученные данные от системы платежа (json)
	 *					status_update	Если установлено в true – статус будет обновлён на success в базе данных компонента
	 */
	/*
	function success($system)
	{
		JHtml::addIncludePath(JPATH_ROOT.'/components/com_joomlakassa/helpers');
		$app = JFactory::getApplication();
		$mnt_transaction_id = $app->input->get("MNT_TRANSACTION_ID", '', 'post');

		$dataSet		= $app->input->getArray($_POST);
		$dataSetJson	= json_encode($dataSet);

		$db		= JFactory::getDBO();
		$query = "SELECT pm_amount FROM #__joomlakassa_orders WHERE ".$db->quoteName('pm_number')." = ".$db->quote($mnt_transaction_id);
		$db->setQuery($query);
		$pmAmount = $db->loadResult();

		return
		[
			"syst_id" => $this->params->def('mnt_id'),
			"syst_name" => $this->params->def('system_name'),
			'syst_extra' => "",
			'pm_number' => $mnt_transaction_id,
			'pm_amount' => $pmAmount,
			'ff_name' => "",
			'ff_email' => "",
			'mob_phone' => "",
			'timestamp' => JHtml::date(strtotime("now"), 'Y-m-d H:i:s'),
			'status' => -1,
			'data_suc' => $dataSetJson,
			'status_update' => true
		];
	}
	*/


	/**
	 * Fail Page (страница неудачного платежа)
	 *
	 * @param	string	$system			Ключ системы платежа
	 *
	 * @return  array	pm_number		ID платежа в компоненте
	 *					data_fail		Данные из запроса (json)
	 *					status_update	Если установлено в true – статус будет обновлён на fail в базе данных компонента
	 */
	// function fail($system) { }

}